@@ -47,6 +47,7 @@ class EWAHDWHookPostgres(EWAHBaseDWHook):
         data,
         table_name,
         schema_name,
+        schema_suffix,
         # database_name,
         columns_definition,
         columns_partial_query,
@@ -54,8 +55,10 @@ class EWAHDWHookPostgres(EWAHBaseDWHook):
         drop_and_replace,
         logging_function,
         upload_chunking=100000,
+        pk_columns=[],
     ):
         logging_function('Preparing DWH Tables...')
+        schema_name += schema_suffix
         if drop_and_replace or (not self.test_if_table_exists(
             table_name=table_name,
             schema_name=schema_name,
@@ -71,6 +74,17 @@ class EWAHDWHookPostgres(EWAHBaseDWHook):
                 }),
                 commit=False,
             )
+            if pk_columns:
+                self.execute(
+                    sql="""
+                        ALTER TABLE ONLY "{schema_name}"."{table_name}"
+                        ADD CONSTRAINT "pkey" PRIMARY KEY ("{columns}");
+                    """.format(
+                        schema_name=schema_name,
+                        table_name=table_name,
+                        columns='","'.join(pk_columns),
+                    )
+                )
 
         if not drop_and_replace and update_on_columns:
             # make sure there is a unique constraint for update_on_columns
