@@ -2,9 +2,15 @@ from ewah.operators.base_operator import EWAHBaseOperator
 from ewah.ewah_utils.airflow_utils import airflow_datetime_adjustments
 from ewah.constants import EWAHConstants as EC
 
+from airflow.hooks.base_hook import BaseHook
+
+from sshtunnel import SSHTunnelForwarder
+from tempfile import NamedTemporaryFile
 from datetime import timedelta
 from pytz import timezone
 
+import os
+
 class EWAHSQLBaseOperator(EWAHBaseOperator):
 
     template_fields = ('data_from', 'data_until', 'reload_data_from')
@@ -33,6 +39,7 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
         #   it is loading incrementally, where to start loading data? datetime
         reload_data_chunking=None, # must be timedelta
         where_clause='1 = 1',
+        tunnel_conn_id=None, # str - name of conn id of SSH tunnel if applicable
     *args, **kwargs):
 
         # allow setting schema in general config w/out throwing an error
@@ -103,6 +110,7 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
         self.chunking_column = chunking_column
         self.reload_data_from = reload_data_from
         self.reload_data_chunking = reload_data_chunking or chunking_interval
+        self.tunnel_conn_id = tunnel_conn_id
 
         # run after setting class properties for templating
         super().__init__(*args, **kwargs)
@@ -149,6 +157,33 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
         })
 
     def ewah_execute(self, context):
+        if self.tunnel_conn_id:
+            # if tunnel_conn_id arg is given, use SSH tunnel to connect!
+            tc = BaseHook.get_connection(self.tunnel_conn_id)
+            rba = (self.upload_hook.credentials.host, self.upload_hook.credentials.port)
+            with NamedTemporaryFile() as temp_file:
+                # write private key into a file to connect to SSH tunnel
+                if tc.extra:
+                    temp_file_name = os.path.abspath(temp_file.name)
+                    temp_file.write(tc.extra.encode())
+                    temp_file.flush()
+                else:
+                    temp_file_name = None
+
+                forwarder_kwargs ={
+                    'ssh_address_or_host': (tc.host, tc.port or 22),
+                    'ssh_username': tc.login or None,
+                    'ssh_pkey': temp_file_name,
+                    'ssh_password': tc.password or None,
+                    'remote_bind_address': rba,
+                }
+                with SSHTunnelForwarder(**forwarder_kwargs) as t:
+                    self.upload_hook.credentials.port = t.local_bind_port
+                    self.sql_execute(context)
+        else:
+            self.sql_execute(context)
+
+    def sql_execute(self, context):
         str_format = '%Y-%m-%dT%H:%M:%SZ'
 
         if not self.drop_and_replace and \
